#!/usr/local/bin/ruby
require 'getoptlong'
require 'open-uri'
require 'net/smtp'

if ARGV.empty? then
  puts "usage: check_url.rb [-v] [-m emailaddr] <url>"
  exit 1
end

# specify options
opts = GetoptLong.new(
  [ "-v", GetoptLong::NO_ARGUMENT ],
  [ "-m", GetoptLong::REQUIRED_ARGUMENT ]
)

smtp_host = "smtp.example.com"
from = "webtest@example.com"
url = ""
message = ""
flag = 0
verbose = 0
# default this
to = "webtest@example.com"

# process args
opts.each do |opt, arg|
  case opt
    when '-v'
      # send OK messages also
      verbose = 1

    when '-m'
      # set the real TO address
      to = arg
  end
end

# test again, did we clobber all the args ?

if ARGV.empty? then
  puts "usage: check_url.rb [-v] [-m emailaddr] <url>"
  exit 1
end

# get the url in question
url = ARGV[0]
subject="Web monitor alert re #{url}"

# go and test the site
begin
  page = open(url).read
  if page =~ /Error|Exception/
    message = "#{url} has returned either Error or Exception"
    flag = 1
  end
rescue
  message = "#{url} Unavailable\n - #{$!.message}"
  flag = 2
end

case flag
  when 0
    # the site is ok
    if verbose
      mail = <<MAIL
Subject: #{subject}

#{url} is feeling OK right now.

Diagnosis: Site up
MAIL

      Net::SMTP.start(smtp_host) do |smtp|
        smtp.send_mail(mail, from, to)
      end
    end
  else
    # The site is busted somehow
    mail = <<MAIL
Subject: #{subject}

Sadly, #{url} isn't feeling well right now.

Diagnosis: #{message}
Page     : #{page}
MAIL

    Net::SMTP.start(smtp_host) do |smtp|
      smtp.send_mail(mail, from, to)
   end
end
